# This file was auto-generated by Fern from our API Definition.

from ....core.pydantic_utilities import UniversalBaseModel
import pydantic
from .inference_request import InferenceRequest
from .state_inference import StateInference
from ....core.pydantic_utilities import IS_PYDANTIC_V2
import typing


class JobInference(UniversalBaseModel):
    job_id: str = pydantic.Field()
    """
    The ID associated with this job.
    """

    request: InferenceRequest = pydantic.Field()
    """
    The request that initiated the job.
    """

    state: StateInference = pydantic.Field()
    """
    The current state of the job.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
