# This file was auto-generated by Fern from our API Definition.

import typing
from .assistant_end import AssistantEnd
from .assistant_message import AssistantMessage
from .chat_metadata import ChatMetadata
from .web_socket_error import WebSocketError
from .user_interruption import UserInterruption
from .user_message import UserMessage
from .tool_call_message import ToolCallMessage
from .tool_response_message import ToolResponseMessage
from .tool_error_message import ToolErrorMessage

JsonMessage = typing.Union[
    AssistantEnd,
    AssistantMessage,
    ChatMetadata,
    WebSocketError,
    UserInterruption,
    UserMessage,
    ToolCallMessage,
    ToolResponseMessage,
    ToolErrorMessage,
]
