# This file was auto-generated by Fern from our API Definition.

import typing
from .state_embedding_generation_queued import StateEmbeddingGenerationQueued
from .state_embedding_generation_in_progress import StateEmbeddingGenerationInProgress
from .state_embedding_generation_completed_embedding_generation import (
    StateEmbeddingGenerationCompletedEmbeddingGeneration,
)
from .state_embedding_generation_failed import StateEmbeddingGenerationFailed

StateEmbeddingGeneration = typing.Union[
    StateEmbeddingGenerationQueued,
    StateEmbeddingGenerationInProgress,
    StateEmbeddingGenerationCompletedEmbeddingGeneration,
    StateEmbeddingGenerationFailed,
]
