# This file was auto-generated by Fern from our API Definition.

from ....core.pydantic_utilities import UniversalBaseModel
import pydantic
from ....core.pydantic_utilities import IS_PYDANTIC_V2
import typing


class CompletedInference(UniversalBaseModel):
    created_timestamp_ms: int = pydantic.Field()
    """
    When this job was created (Unix timestamp in milliseconds).
    """

    started_timestamp_ms: int = pydantic.Field()
    """
    When this job started (Unix timestamp in milliseconds).
    """

    ended_timestamp_ms: int = pydantic.Field()
    """
    When this job ended (Unix timestamp in milliseconds).
    """

    num_predictions: int = pydantic.Field()
    """
    The number of predictions that were generated by this job.
    """

    num_errors: int = pydantic.Field()
    """
    The number of errors that occurred while running this job.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
