# This file was auto-generated by Fern from our API Definition.

from ....core.pydantic_utilities import UniversalBaseModel
import typing
import pydantic
from ....core.pydantic_utilities import IS_PYDANTIC_V2


class JobDetails(UniversalBaseModel):
    """
    If the job_details flag was set in the request, details about the current streaming job will be returned in the response body.
    """

    job_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    ID of the current streaming job.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
