# This file was auto-generated by Fern from our API Definition.

import typing

VoiceNameEnum = typing.Union[
    typing.Literal[
        "ITO",
        "KORA",
        "DACHER",
        "AURA",
        "FINN",
        "SIENNA",
        "WILLOW",
        "SCOUT",
        "WHIMSY",
        "ACE",
        "JUNO",
        "STELLA",
        "HIRO",
        "SUNNY",
    ],
    typing.Any,
]
