# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import pydantic
import typing
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class PostedTimeoutSpec(UniversalBaseModel):
    """
    Settings for a specific timeout to be posted to the server
    """

    enabled: bool = pydantic.Field()
    """
    Boolean indicating if this event message is enabled.
    """

    duration_secs: typing.Optional[int] = pydantic.Field(default=None)
    """
    Duration in seconds for the timeout.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
